# FileSaver.js demo

The following examples demonstrate how it is possible to generate and save any type of data right in the browser using the W3C `saveAs()` FileSaver interface, without contacting any servers.

## Saving an image

Filename: .png

## Saving text

Filename: .txt

## Saving rich text

### Some example rich text

- Plain Boring text.
- Emphasized text!
- Strong text!
- A link.

Filename: .xhtml